@@ -12,6 +12,11 @@ Bio::DB::GFF::Aggregator::transcript -- Transcript aggregator
 				   -aggregator => ['transcript','clone'],
 				 );
 
+ -------------------------------------------------
+ Aggregator method: transcript
+ Main method:       transcript
+ Sub methods:       exon CDS 5'UTR 3'UTR TSS PolyA
+ -------------------------------------------------
 
 =head1 DESCRIPTION
 
@@ -40,11 +45,9 @@ package Bio::DB::GFF::Aggregator::transcript;
 use strict;
 use Bio::DB::GFF::Aggregator;
 
-use vars qw($VERSION @ISA);
+use vars qw(@ISA);
 @ISA = qw(Bio::DB::GFF::Aggregator);
 
-$VERSION = '0.10';
-
 =head2 method
 
  Title   : method
