@@ -3,6 +3,7 @@ use strict;
 use vars qw($USAGE);
 
 use Bio::SeqIO;
+use Bio::PrimarySeq;
 use Getopt::Long;
 my ($length,$type,$filename);
 
@@ -10,7 +11,7 @@ $USAGE = 'usage: generate_random_seq.pl --length=1000 --type=dna --filename=/tmp
 
 my %alphabets = ( 'dna' => [qw(C A G T)],
 		  'rna' => [qw(C A G U)],
-		  'prot'=> [qw( A C D E F G H I K L M N P Q R S T V W X Y)],
+		  'prot'=> [qw( A C D E F G H I K L M N P Q R S T V W Y)],
 	      );
 &GetOptions 
     (
@@ -31,7 +32,7 @@ foreach ( 1..$length ) {
 }
 
 my $seq = new Bio::PrimarySeq(-seq => $sequence, -display_id => 'randomseq');
-my %args = ( '-format' => 'large');
+my %args = ( '-format' => 'fasta');
 if( $filename ) { $args{'-file'} = ">$filename" }
 
 my $seqio =  new Bio::SeqIO(%args);
